@@ -51,7 +51,7 @@ class OAuth2Authenticator:
             client_id=self.client_id,
             client_secret=self.client_secret,
         )
-        state = str(random.randint(0, 65000))
+        state = str(random.randint(0, 65000))  # noqa: S311
         url = reddit.auth.url(scopes=self.scopes, state=state, duration="permanent")
         logger.warning("Authentication action required before the program can proceed")
         logger.warning(f"Authenticate at {url!r} if your browser does not open it for you")
