@@ -27,9 +27,9 @@ def test_process_click_context(arg_dict: dict):
 
 
 def test_yaml_file_read():
-    file = "./tests/yaml_test_configuration.yaml"
+    yaml_file = "./tests/yaml_test_configuration.yaml"
     test_config = Configuration()
-    test_config.parse_yaml_options(file)
+    test_config.parse_yaml_options(yaml_file)
     assert test_config.subreddit == ["EarthPorn", "TwoXChromosomes", "Mindustry"]
     assert test_config.sort == "new"
     assert test_config.limit == 10
